@@ -10,7 +10,8 @@ __all__ = (
     'IMAGE_CREATE_ON_DEMAND',
     'TINYPNG_ALLOWED_EXTENSIONS',
     'TINYPNG_API_KEY_FUNCTION',
-    'TINYPNG_API_KEY'
+    'TINYPNG_API_KEY',
+    'IMAGE_PLACEHOLDER_PATH'
 )
 
 
@@ -48,3 +49,5 @@ TINYPNG_ALLOWED_EXTENSIONS = ['jpeg', 'jpg', 'png']
 TINYPNG_API_KEY_FUNCTION = getattr(settings, 'TINYPNG_API_KEY_FUNCTION', None)
 
 TINYPNG_API_KEY = getattr(settings, 'TINYPNG_API_KEY', None)
+
+IMAGE_PLACEHOLDER_PATH = getattr(settings, 'IMAGE_PLACEHOLDER_PATH', None)
